@@ -1,10 +1,10 @@
-"""Pull requests are always welcomed"""
+"""Pull Requests are always Welcomed"""
 
+import pywhatkit.help
 from pywhatkit.ascii_art import image_to_ascii_art
 from pywhatkit.chr_to_handwriting import text_to_handwriting
-import pywhatkit.help
+from pywhatkit.history import show_history
+from pywhatkit.mail import send_mail, send_hmail
 from pywhatkit.main import print_sleep_time, check_window, sendwhatmsg, sendwhatmsg_to_group, info, playonyt, search, close_tab, sendwhatmsg_instantly, sendwhats_image
 from pywhatkit.sc import shutdown, cancel_shutdown
 from pywhatkit.wwd import tutorial_english, tutorial_hindi, developer_contact, join_discord
-from pywhatkit.history import show_history
-from pywhatkit.mail import send_mail, send_hmail
