@@ -3,19 +3,24 @@ import webbrowser as web
 
 def tutorial_hindi() -> None:
     """Watch tutorial on how to use this library on YouTube in Hindi"""
-    web.open("https://youtu.be/Fy7hmZ_YDjQ")
+
+    web.open("https://youtu.be/o6WV9zFJg1o")
 
 
 def tutorial_english() -> None:
     """Watch tutorial on how to use this library on YouTube in English"""
-    web.open("https://youtu.be/nAjbapi4Qk8")
+
+    web.open("https://youtu.be/vpfrwpO_HKY")
 
 
 def developer_contact() -> None:
     """Contact information of developer for feedbacks"""
-    print("Message me on Telegram, username - Tag_kiya_kya\nOr email me at ankitrajjitendra816@gmail.com.")
+
+    link = "https://github.com/Ankit404butfound/PyWhatKit"
+    print(f"You can reach out to us on GitHub {link} for help regarding any issues related to the module.")
 
 
 def join_discord() -> None:
     """Opens the invite link for the discord server"""
-    web.open("https://discord.gg/NSdZknvDdH")
+
+    web.open("https://discord.gg/62Yf5mushu")
